@@ -49,9 +49,6 @@ lat.set_ticks_visible(False)
 lat.set_ticklabel_visible(False)
 lon.set_ticklabel_visible(False)
 
-lon.coord_wrap = 180 * u.deg
-lon.set_major_formatter('dd')
-
 # Plot the Heliographic Stonyhurst grid
 overlay.grid(color='tab:blue', linewidth=2, linestyle='dashed')
 # Switch off the helioprojective grid
